# coding: utf-8

"""
    result-analysis-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from dhicn_result_analysis_service.api_client import ApiClient
from dhicn_result_analysis_service.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class NetworkApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def api_v1_result_network_dynamic_chainage_get(self, **kwargs):  # noqa: E501
        """Get 1D dynamic chainage results of pipe network (pipe)  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result_network_dynamic_chainage_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[str]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_result_network_dynamic_chainage_get_with_http_info(**kwargs)  # noqa: E501

    def api_v1_result_network_dynamic_chainage_get_with_http_info(self, **kwargs):  # noqa: E501
        """Get 1D dynamic chainage results of pipe network (pipe)  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result_network_dynamic_chainage_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[str], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'scenario_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_result_network_dynamic_chainage_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('ScenarioId', local_var_params['scenario_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/result/network/dynamicChainage', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[str]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_result_network_dynamic_get(self, scenario_id, **kwargs):  # noqa: E501
        """获取管道动态结果 Get 1D dynamic results of pipe network (pipe)  # noqa: E501

        获取一维管道上的动态结果，包括流量、流速、充满度、水位等 Get pipe dynamic results including flow, velocity, filling, water level, etc. of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result_network_dynamic_get(scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param str pipe_data_type: 管道结果类型 pipe result type:  0-PipeFlow;  1-PipeVelocity;  2-PipeFilling;  3-PipeWaterLevel
        :param int frequency: 查询结果的时间频率 time frequency used to get result
        :param str start_time: 查询结果的开始时间 start time used to get result
        :param str end_time: 查询结果的结束时间 end time used to get result
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: BaseDynamicOutput
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_result_network_dynamic_get_with_http_info(scenario_id, **kwargs)  # noqa: E501

    def api_v1_result_network_dynamic_get_with_http_info(self, scenario_id, **kwargs):  # noqa: E501
        """获取管道动态结果 Get 1D dynamic results of pipe network (pipe)  # noqa: E501

        获取一维管道上的动态结果，包括流量、流速、充满度、水位等 Get pipe dynamic results including flow, velocity, filling, water level, etc. of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result_network_dynamic_get_with_http_info(scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param str pipe_data_type: 管道结果类型 pipe result type:  0-PipeFlow;  1-PipeVelocity;  2-PipeFilling;  3-PipeWaterLevel
        :param int frequency: 查询结果的时间频率 time frequency used to get result
        :param str start_time: 查询结果的开始时间 start time used to get result
        :param str end_time: 查询结果的结束时间 end time used to get result
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(BaseDynamicOutput, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'scenario_id',
            'pipe_data_type',
            'frequency',
            'start_time',
            'end_time'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_result_network_dynamic_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'scenario_id' is set
        if self.api_client.client_side_validation and ('scenario_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['scenario_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scenario_id` when calling `api_v1_result_network_dynamic_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'pipe_data_type' in local_var_params and local_var_params['pipe_data_type'] is not None:  # noqa: E501
            query_params.append(('PipeDataType', local_var_params['pipe_data_type']))  # noqa: E501
        if 'frequency' in local_var_params and local_var_params['frequency'] is not None:  # noqa: E501
            query_params.append(('Frequency', local_var_params['frequency']))  # noqa: E501
        if 'start_time' in local_var_params and local_var_params['start_time'] is not None:  # noqa: E501
            query_params.append(('StartTime', local_var_params['start_time']))  # noqa: E501
        if 'end_time' in local_var_params and local_var_params['end_time'] is not None:  # noqa: E501
            query_params.append(('EndTime', local_var_params['end_time']))  # noqa: E501
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('ScenarioId', local_var_params['scenario_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/result/network/dynamic', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BaseDynamicOutput',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_result_network_multipoint_timeseries_get(self, scenario_id, **kwargs):  # noqa: E501
        """获取管道多点时间序列结果 Get pipe network multi-point time series results  # noqa: E501

        获取管道多个计算点上的流量、流速、充满度、水位等时间序列结果 Get pipe flow, velocity, filling, water level, etc. time series result on multiple points of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result_network_multipoint_timeseries_get(scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param str pipe_data_type: 管道结果类型 pipe result type:  0-PipeFlow;  1-PipeVelocity;  2-PipeFilling;  3-PipeWaterLevel
        :param str pipe_id: 管道ID pipe ID
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: BaseTimeseriesOutput
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_result_network_multipoint_timeseries_get_with_http_info(scenario_id, **kwargs)  # noqa: E501

    def api_v1_result_network_multipoint_timeseries_get_with_http_info(self, scenario_id, **kwargs):  # noqa: E501
        """获取管道多点时间序列结果 Get pipe network multi-point time series results  # noqa: E501

        获取管道多个计算点上的流量、流速、充满度、水位等时间序列结果 Get pipe flow, velocity, filling, water level, etc. time series result on multiple points of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result_network_multipoint_timeseries_get_with_http_info(scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param str pipe_data_type: 管道结果类型 pipe result type:  0-PipeFlow;  1-PipeVelocity;  2-PipeFilling;  3-PipeWaterLevel
        :param str pipe_id: 管道ID pipe ID
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(BaseTimeseriesOutput, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'scenario_id',
            'pipe_data_type',
            'pipe_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_result_network_multipoint_timeseries_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'scenario_id' is set
        if self.api_client.client_side_validation and ('scenario_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['scenario_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scenario_id` when calling `api_v1_result_network_multipoint_timeseries_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'pipe_data_type' in local_var_params and local_var_params['pipe_data_type'] is not None:  # noqa: E501
            query_params.append(('PipeDataType', local_var_params['pipe_data_type']))  # noqa: E501
        if 'pipe_id' in local_var_params and local_var_params['pipe_id'] is not None:  # noqa: E501
            query_params.append(('PipeID', local_var_params['pipe_id']))  # noqa: E501
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('ScenarioId', local_var_params['scenario_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/result/network/multipoint_timeseries', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BaseTimeseriesOutput',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_result_network_node_dynamic_get(self, scenario_id, **kwargs):  # noqa: E501
        """获取管道节点上的动态结果 Get 1D dynamic results of pipe network (node)  # noqa: E501

        获取一维管道排口或检查井的溢流动态结果 Get outlet or manhole overflow dynamic results of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result_network_node_dynamic_get(scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param str overflow_node_type: 节点类型 node type:  1-Manhole;  3-Outlet;
        :param int frequency: 查询结果的时间频率 time frequency used to get result
        :param str start_time: 查询结果的开始时间 start time used to get result
        :param str end_time: 查询结果的结束时间 end time used to get result
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: BaseDynamicOutput
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_result_network_node_dynamic_get_with_http_info(scenario_id, **kwargs)  # noqa: E501

    def api_v1_result_network_node_dynamic_get_with_http_info(self, scenario_id, **kwargs):  # noqa: E501
        """获取管道节点上的动态结果 Get 1D dynamic results of pipe network (node)  # noqa: E501

        获取一维管道排口或检查井的溢流动态结果 Get outlet or manhole overflow dynamic results of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result_network_node_dynamic_get_with_http_info(scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param str overflow_node_type: 节点类型 node type:  1-Manhole;  3-Outlet;
        :param int frequency: 查询结果的时间频率 time frequency used to get result
        :param str start_time: 查询结果的开始时间 start time used to get result
        :param str end_time: 查询结果的结束时间 end time used to get result
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(BaseDynamicOutput, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'scenario_id',
            'overflow_node_type',
            'frequency',
            'start_time',
            'end_time'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_result_network_node_dynamic_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'scenario_id' is set
        if self.api_client.client_side_validation and ('scenario_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['scenario_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scenario_id` when calling `api_v1_result_network_node_dynamic_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'overflow_node_type' in local_var_params and local_var_params['overflow_node_type'] is not None:  # noqa: E501
            query_params.append(('OverflowNodeType', local_var_params['overflow_node_type']))  # noqa: E501
        if 'frequency' in local_var_params and local_var_params['frequency'] is not None:  # noqa: E501
            query_params.append(('Frequency', local_var_params['frequency']))  # noqa: E501
        if 'start_time' in local_var_params and local_var_params['start_time'] is not None:  # noqa: E501
            query_params.append(('StartTime', local_var_params['start_time']))  # noqa: E501
        if 'end_time' in local_var_params and local_var_params['end_time'] is not None:  # noqa: E501
            query_params.append(('EndTime', local_var_params['end_time']))  # noqa: E501
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('ScenarioId', local_var_params['scenario_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/result/network/node-dynamic', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BaseDynamicOutput',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_result_network_node_static_get(self, static_type, overflow_node_type, scenario_id, **kwargs):  # noqa: E501
        """获取管道节点统计结果 Get 1D statistic results for networks (node)  # noqa: E501

        获取一维管道排口或检查井的总溢流量、最大瞬时溢流量等统计信息 Get total overflow (m^3)、maximum instantaneous overflow(m^3/s) of each outlet( or each manhole )of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result_network_node_static_get(static_type, overflow_node_type, scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str static_type: 节点统计数据类型 node statistic data type (required)
        :param str overflow_node_type: 节点类型 node type:  1-Manhole;  3-Outlet; (required)
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: BaseStaticOutput
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_result_network_node_static_get_with_http_info(static_type, overflow_node_type, scenario_id, **kwargs)  # noqa: E501

    def api_v1_result_network_node_static_get_with_http_info(self, static_type, overflow_node_type, scenario_id, **kwargs):  # noqa: E501
        """获取管道节点统计结果 Get 1D statistic results for networks (node)  # noqa: E501

        获取一维管道排口或检查井的总溢流量、最大瞬时溢流量等统计信息 Get total overflow (m^3)、maximum instantaneous overflow(m^3/s) of each outlet( or each manhole )of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result_network_node_static_get_with_http_info(static_type, overflow_node_type, scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str static_type: 节点统计数据类型 node statistic data type (required)
        :param str overflow_node_type: 节点类型 node type:  1-Manhole;  3-Outlet; (required)
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(BaseStaticOutput, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'static_type',
            'overflow_node_type',
            'scenario_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_result_network_node_static_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'static_type' is set
        if self.api_client.client_side_validation and ('static_type' not in local_var_params or  # noqa: E501
                                                        local_var_params['static_type'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `static_type` when calling `api_v1_result_network_node_static_get`")  # noqa: E501
        # verify the required parameter 'overflow_node_type' is set
        if self.api_client.client_side_validation and ('overflow_node_type' not in local_var_params or  # noqa: E501
                                                        local_var_params['overflow_node_type'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `overflow_node_type` when calling `api_v1_result_network_node_static_get`")  # noqa: E501
        # verify the required parameter 'scenario_id' is set
        if self.api_client.client_side_validation and ('scenario_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['scenario_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scenario_id` when calling `api_v1_result_network_node_static_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'static_type' in local_var_params and local_var_params['static_type'] is not None:  # noqa: E501
            query_params.append(('StaticType', local_var_params['static_type']))  # noqa: E501
        if 'overflow_node_type' in local_var_params and local_var_params['overflow_node_type'] is not None:  # noqa: E501
            query_params.append(('OverflowNodeType', local_var_params['overflow_node_type']))  # noqa: E501
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('ScenarioId', local_var_params['scenario_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/result/network/node-static', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BaseStaticOutput',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_result_network_node_timeseries_get(self, scenario_id, **kwargs):  # noqa: E501
        """获取管道节点单点时间序列结果 Get pipe network single point time series results (node)  # noqa: E501

        获取管道单个节点上的水位、溢流时间序列结果 Get node water level or overflow time series result on a single node of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result_network_node_timeseries_get(scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param str node_data_type: 节点结果类型 node result type:  0-WaterLevel;  1-Overflow;
        :param str node_id: 节点ID node ID
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: BaseTimeseriesOutput
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_result_network_node_timeseries_get_with_http_info(scenario_id, **kwargs)  # noqa: E501

    def api_v1_result_network_node_timeseries_get_with_http_info(self, scenario_id, **kwargs):  # noqa: E501
        """获取管道节点单点时间序列结果 Get pipe network single point time series results (node)  # noqa: E501

        获取管道单个节点上的水位、溢流时间序列结果 Get node water level or overflow time series result on a single node of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result_network_node_timeseries_get_with_http_info(scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param str node_data_type: 节点结果类型 node result type:  0-WaterLevel;  1-Overflow;
        :param str node_id: 节点ID node ID
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(BaseTimeseriesOutput, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'scenario_id',
            'node_data_type',
            'node_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_result_network_node_timeseries_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'scenario_id' is set
        if self.api_client.client_side_validation and ('scenario_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['scenario_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scenario_id` when calling `api_v1_result_network_node_timeseries_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'node_data_type' in local_var_params and local_var_params['node_data_type'] is not None:  # noqa: E501
            query_params.append(('NodeDataType', local_var_params['node_data_type']))  # noqa: E501
        if 'node_id' in local_var_params and local_var_params['node_id'] is not None:  # noqa: E501
            query_params.append(('NodeId', local_var_params['node_id']))  # noqa: E501
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('ScenarioId', local_var_params['scenario_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/result/network/node-timeseries', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BaseTimeseriesOutput',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_result_network_profile_timeseries_get(self, scenario_id, **kwargs):  # noqa: E501
        """获取管道剖面图数据 Get network profile plot data  # noqa: E501

        获取一段或若干段相连管道的剖面图数据 Get profile plot data of one or several connected pipes of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result_network_profile_timeseries_get(scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param list[str] node_i_ds: 沿着管段的节点ID列表 node IDs along the pipes
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: NetworkProfile
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_result_network_profile_timeseries_get_with_http_info(scenario_id, **kwargs)  # noqa: E501

    def api_v1_result_network_profile_timeseries_get_with_http_info(self, scenario_id, **kwargs):  # noqa: E501
        """获取管道剖面图数据 Get network profile plot data  # noqa: E501

        获取一段或若干段相连管道的剖面图数据 Get profile plot data of one or several connected pipes of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result_network_profile_timeseries_get_with_http_info(scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param list[str] node_i_ds: 沿着管段的节点ID列表 node IDs along the pipes
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(NetworkProfile, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'scenario_id',
            'node_i_ds'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_result_network_profile_timeseries_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'scenario_id' is set
        if self.api_client.client_side_validation and ('scenario_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['scenario_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scenario_id` when calling `api_v1_result_network_profile_timeseries_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'node_i_ds' in local_var_params and local_var_params['node_i_ds'] is not None:  # noqa: E501
            query_params.append(('NodeIDs', local_var_params['node_i_ds']))  # noqa: E501
            collection_formats['NodeIDs'] = 'multi'  # noqa: E501
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('ScenarioId', local_var_params['scenario_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/result/network/profile-timeseries', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='NetworkProfile',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_result_network_pump_statistics_get(self, scenario_id, **kwargs):  # noqa: E501
        """获取管道泵站的统计结果 Get statistic results of network pumps  # noqa: E501

        获取管道泵站的统计结果，包括累计流量、累计开启时长等 Get pipe structure pumps statistic results, including pump accumulated discharge, pump accumulated open time, etc. of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result_network_pump_statistics_get(scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[PumpStatisticsOutput]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_result_network_pump_statistics_get_with_http_info(scenario_id, **kwargs)  # noqa: E501

    def api_v1_result_network_pump_statistics_get_with_http_info(self, scenario_id, **kwargs):  # noqa: E501
        """获取管道泵站的统计结果 Get statistic results of network pumps  # noqa: E501

        获取管道泵站的统计结果，包括累计流量、累计开启时长等 Get pipe structure pumps statistic results, including pump accumulated discharge, pump accumulated open time, etc. of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result_network_pump_statistics_get_with_http_info(scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[PumpStatisticsOutput], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'scenario_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_result_network_pump_statistics_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'scenario_id' is set
        if self.api_client.client_side_validation and ('scenario_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['scenario_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scenario_id` when calling `api_v1_result_network_pump_statistics_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('ScenarioId', local_var_params['scenario_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/result/network/pump-statistics', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[PumpStatisticsOutput]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_result_network_pump_timeseries_get(self, scenario_id, **kwargs):  # noqa: E501
        """获取管道泵站的时间序列结果 Get time-series results of a network pump  # noqa: E501

        获取单个管道泵站的水位、流量时间序列结果数据 Get water level or discharge time series result of a single pump of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result_network_pump_timeseries_get(scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param str pump_id: 泵的ID pump ID
        :param str pump_data_type: 泵的数据类型 pump data type:  0-WaterLevel;  1-Discharge;
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: BaseTimeseriesOutput
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_result_network_pump_timeseries_get_with_http_info(scenario_id, **kwargs)  # noqa: E501

    def api_v1_result_network_pump_timeseries_get_with_http_info(self, scenario_id, **kwargs):  # noqa: E501
        """获取管道泵站的时间序列结果 Get time-series results of a network pump  # noqa: E501

        获取单个管道泵站的水位、流量时间序列结果数据 Get water level or discharge time series result of a single pump of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result_network_pump_timeseries_get_with_http_info(scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param str pump_id: 泵的ID pump ID
        :param str pump_data_type: 泵的数据类型 pump data type:  0-WaterLevel;  1-Discharge;
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(BaseTimeseriesOutput, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'scenario_id',
            'pump_id',
            'pump_data_type'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_result_network_pump_timeseries_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'scenario_id' is set
        if self.api_client.client_side_validation and ('scenario_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['scenario_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scenario_id` when calling `api_v1_result_network_pump_timeseries_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'pump_id' in local_var_params and local_var_params['pump_id'] is not None:  # noqa: E501
            query_params.append(('PumpID', local_var_params['pump_id']))  # noqa: E501
        if 'pump_data_type' in local_var_params and local_var_params['pump_data_type'] is not None:  # noqa: E501
            query_params.append(('PumpDataType', local_var_params['pump_data_type']))  # noqa: E501
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('ScenarioId', local_var_params['scenario_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/result/network/pump-timeseries', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BaseTimeseriesOutput',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_result_network_static_get(self, scenario_id, **kwargs):  # noqa: E501
        """获取管道统计结果 Get 1D statistic results for networks (pipe)  # noqa: E501

        获取一维管道统计结果，包括流量、流速、充满度、水位等的最大值、最小值 Get pipe statistic results including maximum and minimum of flow, velocity, filling, water level, etc. of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result_network_static_get(scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param str pipe_data_type: 管道结果类型 pipe result type:  0-PipeFlow;  1-PipeVelocity;  2-PipeFilling;  3-PipeWaterLevel
        :param str statistic_type: 统计类型 statistic type:  0-Min;  1-Max;
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: BaseStaticOutput
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_result_network_static_get_with_http_info(scenario_id, **kwargs)  # noqa: E501

    def api_v1_result_network_static_get_with_http_info(self, scenario_id, **kwargs):  # noqa: E501
        """获取管道统计结果 Get 1D statistic results for networks (pipe)  # noqa: E501

        获取一维管道统计结果，包括流量、流速、充满度、水位等的最大值、最小值 Get pipe statistic results including maximum and minimum of flow, velocity, filling, water level, etc. of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result_network_static_get_with_http_info(scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param str pipe_data_type: 管道结果类型 pipe result type:  0-PipeFlow;  1-PipeVelocity;  2-PipeFilling;  3-PipeWaterLevel
        :param str statistic_type: 统计类型 statistic type:  0-Min;  1-Max;
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(BaseStaticOutput, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'scenario_id',
            'pipe_data_type',
            'statistic_type'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_result_network_static_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'scenario_id' is set
        if self.api_client.client_side_validation and ('scenario_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['scenario_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scenario_id` when calling `api_v1_result_network_static_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'pipe_data_type' in local_var_params and local_var_params['pipe_data_type'] is not None:  # noqa: E501
            query_params.append(('PipeDataType', local_var_params['pipe_data_type']))  # noqa: E501
        if 'statistic_type' in local_var_params and local_var_params['statistic_type'] is not None:  # noqa: E501
            query_params.append(('StatisticType', local_var_params['statistic_type']))  # noqa: E501
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('ScenarioId', local_var_params['scenario_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/result/network/static', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BaseStaticOutput',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_result_network_statistics_get(self, scenario_id, **kwargs):  # noqa: E501
        """查询管道溢流的统计结果 Get overflow statistic result of the network  # noqa: E501

        查询雨水管道和污水管道的溢流结果，包括总溢流量，溢流点个数等 Get rain pipe and sewage pipe overflow statistic results, including accumulated overflow amount, number of overflow points, etc. of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result_network_statistics_get(scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: NetworkStatisticsOutput
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_result_network_statistics_get_with_http_info(scenario_id, **kwargs)  # noqa: E501

    def api_v1_result_network_statistics_get_with_http_info(self, scenario_id, **kwargs):  # noqa: E501
        """查询管道溢流的统计结果 Get overflow statistic result of the network  # noqa: E501

        查询雨水管道和污水管道的溢流结果，包括总溢流量，溢流点个数等 Get rain pipe and sewage pipe overflow statistic results, including accumulated overflow amount, number of overflow points, etc. of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result_network_statistics_get_with_http_info(scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(NetworkStatisticsOutput, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'scenario_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_result_network_statistics_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'scenario_id' is set
        if self.api_client.client_side_validation and ('scenario_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['scenario_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scenario_id` when calling `api_v1_result_network_statistics_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('ScenarioId', local_var_params['scenario_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/result/network/statistics', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='NetworkStatisticsOutput',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_result_network_timeseries_get(self, scenario_id, **kwargs):  # noqa: E501
        """获取管道单点时间序列结果 Get pipe network single point time series results  # noqa: E501

        获取管道单个计算点上的流量、流速、充满度、水位等时间序列结果 Get pipe flow, velocity, filling, water level, etc. time series result on a single pipe of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result_network_timeseries_get(scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param str pipe_data_type: 管道结果类型 pipe result type:  0-PipeFlow;  1-PipeVelocity;  2-PipeFilling;  3-PipeWaterLevel
        :param str pipe_id: 管道ID pipe ID
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: BaseTimeseriesOutput
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_result_network_timeseries_get_with_http_info(scenario_id, **kwargs)  # noqa: E501

    def api_v1_result_network_timeseries_get_with_http_info(self, scenario_id, **kwargs):  # noqa: E501
        """获取管道单点时间序列结果 Get pipe network single point time series results  # noqa: E501

        获取管道单个计算点上的流量、流速、充满度、水位等时间序列结果 Get pipe flow, velocity, filling, water level, etc. time series result on a single pipe of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result_network_timeseries_get_with_http_info(scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param str pipe_data_type: 管道结果类型 pipe result type:  0-PipeFlow;  1-PipeVelocity;  2-PipeFilling;  3-PipeWaterLevel
        :param str pipe_id: 管道ID pipe ID
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(BaseTimeseriesOutput, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'scenario_id',
            'pipe_data_type',
            'pipe_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_result_network_timeseries_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'scenario_id' is set
        if self.api_client.client_side_validation and ('scenario_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['scenario_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scenario_id` when calling `api_v1_result_network_timeseries_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'pipe_data_type' in local_var_params and local_var_params['pipe_data_type'] is not None:  # noqa: E501
            query_params.append(('PipeDataType', local_var_params['pipe_data_type']))  # noqa: E501
        if 'pipe_id' in local_var_params and local_var_params['pipe_id'] is not None:  # noqa: E501
            query_params.append(('PipeID', local_var_params['pipe_id']))  # noqa: E501
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('ScenarioId', local_var_params['scenario_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/result/network/timeseries', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BaseTimeseriesOutput',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_result_network_valve_statistics_get(self, scenario_id, **kwargs):  # noqa: E501
        """获取管道阀门的统计结果 Get statistic results of network valves  # noqa: E501

        获取管道阀门的统计结果，包括累计开启时长等 Get pipe structure valves statistic results, including valve accumulated open time, etc. of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result_network_valve_statistics_get(scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[ValveStatisticsOutput]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_result_network_valve_statistics_get_with_http_info(scenario_id, **kwargs)  # noqa: E501

    def api_v1_result_network_valve_statistics_get_with_http_info(self, scenario_id, **kwargs):  # noqa: E501
        """获取管道阀门的统计结果 Get statistic results of network valves  # noqa: E501

        获取管道阀门的统计结果，包括累计开启时长等 Get pipe structure valves statistic results, including valve accumulated open time, etc. of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result_network_valve_statistics_get_with_http_info(scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[ValveStatisticsOutput], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'scenario_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_result_network_valve_statistics_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'scenario_id' is set
        if self.api_client.client_side_validation and ('scenario_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['scenario_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scenario_id` when calling `api_v1_result_network_valve_statistics_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('ScenarioId', local_var_params['scenario_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/result/network/valve-statistics', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[ValveStatisticsOutput]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    IoT服务

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_iot_service.configuration import Configuration


class SaveTelemetryDataInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'device_id': 'str',
        'telemetry_data_json': 'str',
        'use_rule': 'bool'
    }

    attribute_map = {
        'device_id': 'deviceId',
        'telemetry_data_json': 'telemetryDataJson',
        'use_rule': 'useRule'
    }

    def __init__(self, device_id=None, telemetry_data_json=None, use_rule=None, local_vars_configuration=None):  # noqa: E501
        """SaveTelemetryDataInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._device_id = None
        self._telemetry_data_json = None
        self._use_rule = None
        self.discriminator = None

        self.device_id = device_id
        self.telemetry_data_json = telemetry_data_json
        if use_rule is not None:
            self.use_rule = use_rule

    @property
    def device_id(self):
        """Gets the device_id of this SaveTelemetryDataInput.  # noqa: E501

        设备ID device Id  # noqa: E501

        :return: The device_id of this SaveTelemetryDataInput.  # noqa: E501
        :rtype: str
        """
        return self._device_id

    @device_id.setter
    def device_id(self, device_id):
        """Sets the device_id of this SaveTelemetryDataInput.

        设备ID device Id  # noqa: E501

        :param device_id: The device_id of this SaveTelemetryDataInput.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and device_id is None:  # noqa: E501
            raise ValueError("Invalid value for `device_id`, must not be `None`")  # noqa: E501

        self._device_id = device_id

    @property
    def telemetry_data_json(self):
        """Gets the telemetry_data_json of this SaveTelemetryDataInput.  # noqa: E501

        时间序列数据，JSON格式 time-series data in json format  Json:  {\"temperature\": 26}  {\"ts\":1634712287000,\"values\":{\"temperature\":26, \"humidity\":87}}  [{\"ts\":1634712287000,\"values\":{\"temperature\":26, \"humidity\":87}}, {\"ts\":1634712588000,\"values\":{\"temperature\":25, \"humidity\":88}}]  # noqa: E501

        :return: The telemetry_data_json of this SaveTelemetryDataInput.  # noqa: E501
        :rtype: str
        """
        return self._telemetry_data_json

    @telemetry_data_json.setter
    def telemetry_data_json(self, telemetry_data_json):
        """Sets the telemetry_data_json of this SaveTelemetryDataInput.

        时间序列数据，JSON格式 time-series data in json format  Json:  {\"temperature\": 26}  {\"ts\":1634712287000,\"values\":{\"temperature\":26, \"humidity\":87}}  [{\"ts\":1634712287000,\"values\":{\"temperature\":26, \"humidity\":87}}, {\"ts\":1634712588000,\"values\":{\"temperature\":25, \"humidity\":88}}]  # noqa: E501

        :param telemetry_data_json: The telemetry_data_json of this SaveTelemetryDataInput.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and telemetry_data_json is None:  # noqa: E501
            raise ValueError("Invalid value for `telemetry_data_json`, must not be `None`")  # noqa: E501

        self._telemetry_data_json = telemetry_data_json

    @property
    def use_rule(self):
        """Gets the use_rule of this SaveTelemetryDataInput.  # noqa: E501

        是否启用规则，默认不启用  use rule engine or not, default false  # noqa: E501

        :return: The use_rule of this SaveTelemetryDataInput.  # noqa: E501
        :rtype: bool
        """
        return self._use_rule

    @use_rule.setter
    def use_rule(self, use_rule):
        """Sets the use_rule of this SaveTelemetryDataInput.

        是否启用规则，默认不启用  use rule engine or not, default false  # noqa: E501

        :param use_rule: The use_rule of this SaveTelemetryDataInput.  # noqa: E501
        :type: bool
        """

        self._use_rule = use_rule

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SaveTelemetryDataInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SaveTelemetryDataInput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    model-driver-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_model_driver_service.configuration import Configuration


class CalculateStatusOutput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'queue_id': 'str',
        'scenario_id': 'str',
        'status': 'EnumStatus',
        'status_desc': 'str',
        'progress': 'float',
        'waiting_no': 'int'
    }

    attribute_map = {
        'queue_id': 'queueId',
        'scenario_id': 'scenarioId',
        'status': 'status',
        'status_desc': 'statusDesc',
        'progress': 'progress',
        'waiting_no': 'waitingNo'
    }

    def __init__(self, queue_id=None, scenario_id=None, status=None, status_desc=None, progress=None, waiting_no=None, local_vars_configuration=None):  # noqa: E501
        """CalculateStatusOutput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._queue_id = None
        self._scenario_id = None
        self._status = None
        self._status_desc = None
        self._progress = None
        self._waiting_no = None
        self.discriminator = None

        self.queue_id = queue_id
        if scenario_id is not None:
            self.scenario_id = scenario_id
        if status is not None:
            self.status = status
        self.status_desc = status_desc
        self.progress = progress
        self.waiting_no = waiting_no

    @property
    def queue_id(self):
        """Gets the queue_id of this CalculateStatusOutput.  # noqa: E501

        排队ID  # noqa: E501

        :return: The queue_id of this CalculateStatusOutput.  # noqa: E501
        :rtype: str
        """
        return self._queue_id

    @queue_id.setter
    def queue_id(self, queue_id):
        """Sets the queue_id of this CalculateStatusOutput.

        排队ID  # noqa: E501

        :param queue_id: The queue_id of this CalculateStatusOutput.  # noqa: E501
        :type: str
        """

        self._queue_id = queue_id

    @property
    def scenario_id(self):
        """Gets the scenario_id of this CalculateStatusOutput.  # noqa: E501

        方案ID  # noqa: E501

        :return: The scenario_id of this CalculateStatusOutput.  # noqa: E501
        :rtype: str
        """
        return self._scenario_id

    @scenario_id.setter
    def scenario_id(self, scenario_id):
        """Sets the scenario_id of this CalculateStatusOutput.

        方案ID  # noqa: E501

        :param scenario_id: The scenario_id of this CalculateStatusOutput.  # noqa: E501
        :type: str
        """

        self._scenario_id = scenario_id

    @property
    def status(self):
        """Gets the status of this CalculateStatusOutput.  # noqa: E501


        :return: The status of this CalculateStatusOutput.  # noqa: E501
        :rtype: EnumStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this CalculateStatusOutput.


        :param status: The status of this CalculateStatusOutput.  # noqa: E501
        :type: EnumStatus
        """

        self._status = status

    @property
    def status_desc(self):
        """Gets the status_desc of this CalculateStatusOutput.  # noqa: E501

        计算状态描述  # noqa: E501

        :return: The status_desc of this CalculateStatusOutput.  # noqa: E501
        :rtype: str
        """
        return self._status_desc

    @status_desc.setter
    def status_desc(self, status_desc):
        """Sets the status_desc of this CalculateStatusOutput.

        计算状态描述  # noqa: E501

        :param status_desc: The status_desc of this CalculateStatusOutput.  # noqa: E501
        :type: str
        """

        self._status_desc = status_desc

    @property
    def progress(self):
        """Gets the progress of this CalculateStatusOutput.  # noqa: E501

        计算进度  # noqa: E501

        :return: The progress of this CalculateStatusOutput.  # noqa: E501
        :rtype: float
        """
        return self._progress

    @progress.setter
    def progress(self, progress):
        """Sets the progress of this CalculateStatusOutput.

        计算进度  # noqa: E501

        :param progress: The progress of this CalculateStatusOutput.  # noqa: E501
        :type: float
        """

        self._progress = progress

    @property
    def waiting_no(self):
        """Gets the waiting_no of this CalculateStatusOutput.  # noqa: E501

        排队序号  # noqa: E501

        :return: The waiting_no of this CalculateStatusOutput.  # noqa: E501
        :rtype: int
        """
        return self._waiting_no

    @waiting_no.setter
    def waiting_no(self, waiting_no):
        """Sets the waiting_no of this CalculateStatusOutput.

        排队序号  # noqa: E501

        :param waiting_no: The waiting_no of this CalculateStatusOutput.  # noqa: E501
        :type: int
        """

        self._waiting_no = waiting_no

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CalculateStatusOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CalculateStatusOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    digital-twin-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_digital_twin_service.configuration import Configuration


class QueryModelPointByConditionInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'template_scenario_id': 'str',
        'model_point_type': 'str',
        'attributes': 'list[AttributeConditionInput]'
    }

    attribute_map = {
        'template_scenario_id': 'templateScenarioId',
        'model_point_type': 'modelPointType',
        'attributes': 'attributes'
    }

    def __init__(self, template_scenario_id=None, model_point_type=None, attributes=None, local_vars_configuration=None):  # noqa: E501
        """QueryModelPointByConditionInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._template_scenario_id = None
        self._model_point_type = None
        self._attributes = None
        self.discriminator = None

        self.template_scenario_id = template_scenario_id
        self.model_point_type = model_point_type
        self.attributes = attributes

    @property
    def template_scenario_id(self):
        """Gets the template_scenario_id of this QueryModelPointByConditionInput.  # noqa: E501

        模板方案ID template scenario id  # noqa: E501

        :return: The template_scenario_id of this QueryModelPointByConditionInput.  # noqa: E501
        :rtype: str
        """
        return self._template_scenario_id

    @template_scenario_id.setter
    def template_scenario_id(self, template_scenario_id):
        """Sets the template_scenario_id of this QueryModelPointByConditionInput.

        模板方案ID template scenario id  # noqa: E501

        :param template_scenario_id: The template_scenario_id of this QueryModelPointByConditionInput.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and template_scenario_id is None:  # noqa: E501
            raise ValueError("Invalid value for `template_scenario_id`, must not be `None`")  # noqa: E501

        self._template_scenario_id = template_scenario_id

    @property
    def model_point_type(self):
        """Gets the model_point_type of this QueryModelPointByConditionInput.  # noqa: E501

        模型点位类型 model point type  # noqa: E501

        :return: The model_point_type of this QueryModelPointByConditionInput.  # noqa: E501
        :rtype: str
        """
        return self._model_point_type

    @model_point_type.setter
    def model_point_type(self, model_point_type):
        """Sets the model_point_type of this QueryModelPointByConditionInput.

        模型点位类型 model point type  # noqa: E501

        :param model_point_type: The model_point_type of this QueryModelPointByConditionInput.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and model_point_type is None:  # noqa: E501
            raise ValueError("Invalid value for `model_point_type`, must not be `None`")  # noqa: E501

        self._model_point_type = model_point_type

    @property
    def attributes(self):
        """Gets the attributes of this QueryModelPointByConditionInput.  # noqa: E501

        属性条件 Condition  # noqa: E501

        :return: The attributes of this QueryModelPointByConditionInput.  # noqa: E501
        :rtype: list[AttributeConditionInput]
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """Sets the attributes of this QueryModelPointByConditionInput.

        属性条件 Condition  # noqa: E501

        :param attributes: The attributes of this QueryModelPointByConditionInput.  # noqa: E501
        :type: list[AttributeConditionInput]
        """
        if self.local_vars_configuration.client_side_validation and attributes is None:  # noqa: E501
            raise ValueError("Invalid value for `attributes`, must not be `None`")  # noqa: E501

        self._attributes = attributes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, QueryModelPointByConditionInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, QueryModelPointByConditionInput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    result-analysis-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_result_analysis_service.configuration import Configuration


class ModelResultRiverDamStatisticOutput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'asset_id': 'str',
        'asset_name': 'str',
        'max_water_level': 'float',
        'min_water_level': 'float'
    }

    attribute_map = {
        'asset_id': 'assetID',
        'asset_name': 'assetName',
        'max_water_level': 'maxWaterLevel',
        'min_water_level': 'minWaterLevel'
    }

    def __init__(self, asset_id=None, asset_name=None, max_water_level=None, min_water_level=None, local_vars_configuration=None):  # noqa: E501
        """ModelResultRiverDamStatisticOutput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._asset_id = None
        self._asset_name = None
        self._max_water_level = None
        self._min_water_level = None
        self.discriminator = None

        self.asset_id = asset_id
        self.asset_name = asset_name
        if max_water_level is not None:
            self.max_water_level = max_water_level
        if min_water_level is not None:
            self.min_water_level = min_water_level

    @property
    def asset_id(self):
        """Gets the asset_id of this ModelResultRiverDamStatisticOutput.  # noqa: E501

        坝id dam id  # noqa: E501

        :return: The asset_id of this ModelResultRiverDamStatisticOutput.  # noqa: E501
        :rtype: str
        """
        return self._asset_id

    @asset_id.setter
    def asset_id(self, asset_id):
        """Sets the asset_id of this ModelResultRiverDamStatisticOutput.

        坝id dam id  # noqa: E501

        :param asset_id: The asset_id of this ModelResultRiverDamStatisticOutput.  # noqa: E501
        :type: str
        """

        self._asset_id = asset_id

    @property
    def asset_name(self):
        """Gets the asset_name of this ModelResultRiverDamStatisticOutput.  # noqa: E501

        坝名称 dam name  # noqa: E501

        :return: The asset_name of this ModelResultRiverDamStatisticOutput.  # noqa: E501
        :rtype: str
        """
        return self._asset_name

    @asset_name.setter
    def asset_name(self, asset_name):
        """Sets the asset_name of this ModelResultRiverDamStatisticOutput.

        坝名称 dam name  # noqa: E501

        :param asset_name: The asset_name of this ModelResultRiverDamStatisticOutput.  # noqa: E501
        :type: str
        """

        self._asset_name = asset_name

    @property
    def max_water_level(self):
        """Gets the max_water_level of this ModelResultRiverDamStatisticOutput.  # noqa: E501

        最高控制水位 maximum control water level  # noqa: E501

        :return: The max_water_level of this ModelResultRiverDamStatisticOutput.  # noqa: E501
        :rtype: float
        """
        return self._max_water_level

    @max_water_level.setter
    def max_water_level(self, max_water_level):
        """Sets the max_water_level of this ModelResultRiverDamStatisticOutput.

        最高控制水位 maximum control water level  # noqa: E501

        :param max_water_level: The max_water_level of this ModelResultRiverDamStatisticOutput.  # noqa: E501
        :type: float
        """

        self._max_water_level = max_water_level

    @property
    def min_water_level(self):
        """Gets the min_water_level of this ModelResultRiverDamStatisticOutput.  # noqa: E501

        最低控制水位 Minimum control water level  # noqa: E501

        :return: The min_water_level of this ModelResultRiverDamStatisticOutput.  # noqa: E501
        :rtype: float
        """
        return self._min_water_level

    @min_water_level.setter
    def min_water_level(self, min_water_level):
        """Sets the min_water_level of this ModelResultRiverDamStatisticOutput.

        最低控制水位 Minimum control water level  # noqa: E501

        :param min_water_level: The min_water_level of this ModelResultRiverDamStatisticOutput.  # noqa: E501
        :type: float
        """

        self._min_water_level = min_water_level

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ModelResultRiverDamStatisticOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ModelResultRiverDamStatisticOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa
"""
    model-driver-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from dhicn_model_driver_service.models.calculate_logs_output import CalculateLogsOutput
from dhicn_model_driver_service.models.calculate_status_output import CalculateStatusOutput
from dhicn_model_driver_service.models.cancel_result import CancelResult
from dhicn_model_driver_service.models.enum_status import EnumStatus
from dhicn_model_driver_service.models.model_driver_dto import ModelDriverDto
from dhicn_model_driver_service.models.model_operation_result import ModelOperationResult
from dhicn_model_driver_service.models.model_state import ModelState
from dhicn_model_driver_service.models.model_type_para import ModelTypePara
from dhicn_model_driver_service.models.project_scenario import ProjectScenario
from dhicn_model_driver_service.models.scenario_ids import ScenarioIds
from dhicn_model_driver_service.models.scenario_model_message import ScenarioModelMessage
from dhicn_model_driver_service.models.scenario_model_message_input import ScenarioModelMessageInput
from dhicn_model_driver_service.models.scenario_model_status_message import ScenarioModelStatusMessage
from dhicn_model_driver_service.models.update_record_input import UpdateRecordInput



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from dhicn_document_service.api.document_api import DocumentApi
from dhicn_document_service.api.health_api import HealthApi



# coding: utf-8

"""
    model-driver-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_model_driver_service.configuration import Configuration


class ModelDriverDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'project_name': 'str',
        'tenant_id': 'str',
        'scenario_id': 'str',
        'model_type': 'str',
        'priority': 'int',
        'model_info': 'str',
        'compute_begin_time': 'datetime',
        'compute_end_time': 'datetime',
        'compute_node': 'str',
        'create_time': 'datetime',
        'status': 'EnumStatus',
        'sequence_number': 'int',
        'log_path': 'str'
    }

    attribute_map = {
        'id': 'id',
        'project_name': 'projectName',
        'tenant_id': 'tenantId',
        'scenario_id': 'scenarioId',
        'model_type': 'modelType',
        'priority': 'priority',
        'model_info': 'modelInfo',
        'compute_begin_time': 'computeBeginTime',
        'compute_end_time': 'computeEndTime',
        'compute_node': 'computeNode',
        'create_time': 'createTime',
        'status': 'status',
        'sequence_number': 'sequenceNumber',
        'log_path': 'logPath'
    }

    def __init__(self, id=None, project_name=None, tenant_id=None, scenario_id=None, model_type=None, priority=None, model_info=None, compute_begin_time=None, compute_end_time=None, compute_node=None, create_time=None, status=None, sequence_number=None, log_path=None, local_vars_configuration=None):  # noqa: E501
        """ModelDriverDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._project_name = None
        self._tenant_id = None
        self._scenario_id = None
        self._model_type = None
        self._priority = None
        self._model_info = None
        self._compute_begin_time = None
        self._compute_end_time = None
        self._compute_node = None
        self._create_time = None
        self._status = None
        self._sequence_number = None
        self._log_path = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.project_name = project_name
        if tenant_id is not None:
            self.tenant_id = tenant_id
        if scenario_id is not None:
            self.scenario_id = scenario_id
        self.model_type = model_type
        if priority is not None:
            self.priority = priority
        self.model_info = model_info
        if compute_begin_time is not None:
            self.compute_begin_time = compute_begin_time
        if compute_end_time is not None:
            self.compute_end_time = compute_end_time
        self.compute_node = compute_node
        if create_time is not None:
            self.create_time = create_time
        if status is not None:
            self.status = status
        if sequence_number is not None:
            self.sequence_number = sequence_number
        self.log_path = log_path

    @property
    def id(self):
        """Gets the id of this ModelDriverDto.  # noqa: E501

        Id  # noqa: E501

        :return: The id of this ModelDriverDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ModelDriverDto.

        Id  # noqa: E501

        :param id: The id of this ModelDriverDto.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def project_name(self):
        """Gets the project_name of this ModelDriverDto.  # noqa: E501

        项目名称  # noqa: E501

        :return: The project_name of this ModelDriverDto.  # noqa: E501
        :rtype: str
        """
        return self._project_name

    @project_name.setter
    def project_name(self, project_name):
        """Sets the project_name of this ModelDriverDto.

        项目名称  # noqa: E501

        :param project_name: The project_name of this ModelDriverDto.  # noqa: E501
        :type: str
        """

        self._project_name = project_name

    @property
    def tenant_id(self):
        """Gets the tenant_id of this ModelDriverDto.  # noqa: E501

        租户ID  # noqa: E501

        :return: The tenant_id of this ModelDriverDto.  # noqa: E501
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this ModelDriverDto.

        租户ID  # noqa: E501

        :param tenant_id: The tenant_id of this ModelDriverDto.  # noqa: E501
        :type: str
        """

        self._tenant_id = tenant_id

    @property
    def scenario_id(self):
        """Gets the scenario_id of this ModelDriverDto.  # noqa: E501

        方案Id  # noqa: E501

        :return: The scenario_id of this ModelDriverDto.  # noqa: E501
        :rtype: str
        """
        return self._scenario_id

    @scenario_id.setter
    def scenario_id(self, scenario_id):
        """Sets the scenario_id of this ModelDriverDto.

        方案Id  # noqa: E501

        :param scenario_id: The scenario_id of this ModelDriverDto.  # noqa: E501
        :type: str
        """

        self._scenario_id = scenario_id

    @property
    def model_type(self):
        """Gets the model_type of this ModelDriverDto.  # noqa: E501

        模型类型  # noqa: E501

        :return: The model_type of this ModelDriverDto.  # noqa: E501
        :rtype: str
        """
        return self._model_type

    @model_type.setter
    def model_type(self, model_type):
        """Sets the model_type of this ModelDriverDto.

        模型类型  # noqa: E501

        :param model_type: The model_type of this ModelDriverDto.  # noqa: E501
        :type: str
        """

        self._model_type = model_type

    @property
    def priority(self):
        """Gets the priority of this ModelDriverDto.  # noqa: E501

        优先级  # noqa: E501

        :return: The priority of this ModelDriverDto.  # noqa: E501
        :rtype: int
        """
        return self._priority

    @priority.setter
    def priority(self, priority):
        """Sets the priority of this ModelDriverDto.

        优先级  # noqa: E501

        :param priority: The priority of this ModelDriverDto.  # noqa: E501
        :type: int
        """

        self._priority = priority

    @property
    def model_info(self):
        """Gets the model_info of this ModelDriverDto.  # noqa: E501

        模型信息  # noqa: E501

        :return: The model_info of this ModelDriverDto.  # noqa: E501
        :rtype: str
        """
        return self._model_info

    @model_info.setter
    def model_info(self, model_info):
        """Sets the model_info of this ModelDriverDto.

        模型信息  # noqa: E501

        :param model_info: The model_info of this ModelDriverDto.  # noqa: E501
        :type: str
        """

        self._model_info = model_info

    @property
    def compute_begin_time(self):
        """Gets the compute_begin_time of this ModelDriverDto.  # noqa: E501

        计算开始时间  # noqa: E501

        :return: The compute_begin_time of this ModelDriverDto.  # noqa: E501
        :rtype: datetime
        """
        return self._compute_begin_time

    @compute_begin_time.setter
    def compute_begin_time(self, compute_begin_time):
        """Sets the compute_begin_time of this ModelDriverDto.

        计算开始时间  # noqa: E501

        :param compute_begin_time: The compute_begin_time of this ModelDriverDto.  # noqa: E501
        :type: datetime
        """

        self._compute_begin_time = compute_begin_time

    @property
    def compute_end_time(self):
        """Gets the compute_end_time of this ModelDriverDto.  # noqa: E501

        计算结束时间  # noqa: E501

        :return: The compute_end_time of this ModelDriverDto.  # noqa: E501
        :rtype: datetime
        """
        return self._compute_end_time

    @compute_end_time.setter
    def compute_end_time(self, compute_end_time):
        """Sets the compute_end_time of this ModelDriverDto.

        计算结束时间  # noqa: E501

        :param compute_end_time: The compute_end_time of this ModelDriverDto.  # noqa: E501
        :type: datetime
        """

        self._compute_end_time = compute_end_time

    @property
    def compute_node(self):
        """Gets the compute_node of this ModelDriverDto.  # noqa: E501

        计算节点  # noqa: E501

        :return: The compute_node of this ModelDriverDto.  # noqa: E501
        :rtype: str
        """
        return self._compute_node

    @compute_node.setter
    def compute_node(self, compute_node):
        """Sets the compute_node of this ModelDriverDto.

        计算节点  # noqa: E501

        :param compute_node: The compute_node of this ModelDriverDto.  # noqa: E501
        :type: str
        """

        self._compute_node = compute_node

    @property
    def create_time(self):
        """Gets the create_time of this ModelDriverDto.  # noqa: E501

        创建时间  # noqa: E501

        :return: The create_time of this ModelDriverDto.  # noqa: E501
        :rtype: datetime
        """
        return self._create_time

    @create_time.setter
    def create_time(self, create_time):
        """Sets the create_time of this ModelDriverDto.

        创建时间  # noqa: E501

        :param create_time: The create_time of this ModelDriverDto.  # noqa: E501
        :type: datetime
        """

        self._create_time = create_time

    @property
    def status(self):
        """Gets the status of this ModelDriverDto.  # noqa: E501


        :return: The status of this ModelDriverDto.  # noqa: E501
        :rtype: EnumStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ModelDriverDto.


        :param status: The status of this ModelDriverDto.  # noqa: E501
        :type: EnumStatus
        """

        self._status = status

    @property
    def sequence_number(self):
        """Gets the sequence_number of this ModelDriverDto.  # noqa: E501

        Todo  # noqa: E501

        :return: The sequence_number of this ModelDriverDto.  # noqa: E501
        :rtype: int
        """
        return self._sequence_number

    @sequence_number.setter
    def sequence_number(self, sequence_number):
        """Sets the sequence_number of this ModelDriverDto.

        Todo  # noqa: E501

        :param sequence_number: The sequence_number of this ModelDriverDto.  # noqa: E501
        :type: int
        """

        self._sequence_number = sequence_number

    @property
    def log_path(self):
        """Gets the log_path of this ModelDriverDto.  # noqa: E501

        日志存储路径  # noqa: E501

        :return: The log_path of this ModelDriverDto.  # noqa: E501
        :rtype: str
        """
        return self._log_path

    @log_path.setter
    def log_path(self, log_path):
        """Sets the log_path of this ModelDriverDto.

        日志存储路径  # noqa: E501

        :param log_path: The log_path of this ModelDriverDto.  # noqa: E501
        :type: str
        """

        self._log_path = log_path

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ModelDriverDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ModelDriverDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    identity-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_identity_service.configuration import Configuration


class TenantPersonalizedInfoDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'title': 'str',
        'icon': 'str',
        'logo': 'str',
        'cover_type': 'int',
        'cover': 'str'
    }

    attribute_map = {
        'title': 'title',
        'icon': 'icon',
        'logo': 'logo',
        'cover_type': 'coverType',
        'cover': 'cover'
    }

    def __init__(self, title=None, icon=None, logo=None, cover_type=None, cover=None, local_vars_configuration=None):  # noqa: E501
        """TenantPersonalizedInfoDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._title = None
        self._icon = None
        self._logo = None
        self._cover_type = None
        self._cover = None
        self.discriminator = None

        self.title = title
        self.icon = icon
        self.logo = logo
        self.cover_type = cover_type
        self.cover = cover

    @property
    def title(self):
        """Gets the title of this TenantPersonalizedInfoDto.  # noqa: E501

        页面标题 page title  # noqa: E501

        :return: The title of this TenantPersonalizedInfoDto.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this TenantPersonalizedInfoDto.

        页面标题 page title  # noqa: E501

        :param title: The title of this TenantPersonalizedInfoDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and title is None:  # noqa: E501
            raise ValueError("Invalid value for `title`, must not be `None`")  # noqa: E501

        self._title = title

    @property
    def icon(self):
        """Gets the icon of this TenantPersonalizedInfoDto.  # noqa: E501

        租户浏览器图标/客户端软件小图标 browser / client application icon  # noqa: E501

        :return: The icon of this TenantPersonalizedInfoDto.  # noqa: E501
        :rtype: str
        """
        return self._icon

    @icon.setter
    def icon(self, icon):
        """Sets the icon of this TenantPersonalizedInfoDto.

        租户浏览器图标/客户端软件小图标 browser / client application icon  # noqa: E501

        :param icon: The icon of this TenantPersonalizedInfoDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and icon is None:  # noqa: E501
            raise ValueError("Invalid value for `icon`, must not be `None`")  # noqa: E501

        self._icon = icon

    @property
    def logo(self):
        """Gets the logo of this TenantPersonalizedInfoDto.  # noqa: E501

        租户系统Logo tenant system logo  # noqa: E501

        :return: The logo of this TenantPersonalizedInfoDto.  # noqa: E501
        :rtype: str
        """
        return self._logo

    @logo.setter
    def logo(self, logo):
        """Sets the logo of this TenantPersonalizedInfoDto.

        租户系统Logo tenant system logo  # noqa: E501

        :param logo: The logo of this TenantPersonalizedInfoDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and logo is None:  # noqa: E501
            raise ValueError("Invalid value for `logo`, must not be `None`")  # noqa: E501

        self._logo = logo

    @property
    def cover_type(self):
        """Gets the cover_type of this TenantPersonalizedInfoDto.  # noqa: E501

        封面类型 cover type  # noqa: E501

        :return: The cover_type of this TenantPersonalizedInfoDto.  # noqa: E501
        :rtype: int
        """
        return self._cover_type

    @cover_type.setter
    def cover_type(self, cover_type):
        """Sets the cover_type of this TenantPersonalizedInfoDto.

        封面类型 cover type  # noqa: E501

        :param cover_type: The cover_type of this TenantPersonalizedInfoDto.  # noqa: E501
        :type: int
        """
        allowed_values = [None,0, 1]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and cover_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `cover_type` ({0}), must be one of {1}"  # noqa: E501
                .format(cover_type, allowed_values)
            )

        self._cover_type = cover_type

    @property
    def cover(self):
        """Gets the cover of this TenantPersonalizedInfoDto.  # noqa: E501

        封面文件相对路径 cover relative path  # noqa: E501

        :return: The cover of this TenantPersonalizedInfoDto.  # noqa: E501
        :rtype: str
        """
        return self._cover

    @cover.setter
    def cover(self, cover):
        """Sets the cover of this TenantPersonalizedInfoDto.

        封面文件相对路径 cover relative path  # noqa: E501

        :param cover: The cover of this TenantPersonalizedInfoDto.  # noqa: E501
        :type: str
        """

        self._cover = cover

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TenantPersonalizedInfoDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TenantPersonalizedInfoDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    model-configuration-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from dhicn_model_configuration_service.api_client import ApiClient
from dhicn_model_configuration_service.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class ModelTemplateApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def api_v2_model_configuration_template_create_model_template_post(self, **kwargs):  # noqa: E501
        """标记模板模型文件 Mark a template file  # noqa: E501

        把上传的模板模型文件标记为可作为模板方案的模型 Mark a template file as model file that can be used to create a template scenario  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v2_model_configuration_template_create_model_template_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CreateTemplateFileInputV2 create_template_file_input_v2:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v2_model_configuration_template_create_model_template_post_with_http_info(**kwargs)  # noqa: E501

    def api_v2_model_configuration_template_create_model_template_post_with_http_info(self, **kwargs):  # noqa: E501
        """标记模板模型文件 Mark a template file  # noqa: E501

        把上传的模板模型文件标记为可作为模板方案的模型 Mark a template file as model file that can be used to create a template scenario  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v2_model_configuration_template_create_model_template_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CreateTemplateFileInputV2 create_template_file_input_v2:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(str, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'create_template_file_input_v2'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v2_model_configuration_template_create_model_template_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'create_template_file_input_v2' in local_var_params:
            body_params = local_var_params['create_template_file_input_v2']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/model-configuration/template/create-model-template', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v2_model_configuration_template_delete_post(self, **kwargs):  # noqa: E501
        """删除模板模型文件 Delete template files  # noqa: E501

        根据文件ID删除若干个模板模型文件 Delete template files with template file ids  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v2_model_configuration_template_delete_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] request_body:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v2_model_configuration_template_delete_post_with_http_info(**kwargs)  # noqa: E501

    def api_v2_model_configuration_template_delete_post_with_http_info(self, **kwargs):  # noqa: E501
        """删除模板模型文件 Delete template files  # noqa: E501

        根据文件ID删除若干个模板模型文件 Delete template files with template file ids  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v2_model_configuration_template_delete_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] request_body:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(bool, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'request_body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v2_model_configuration_template_delete_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request_body' in local_var_params:
            body_params = local_var_params['request_body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/model-configuration/template/delete', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='bool',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v2_model_configuration_template_download_model_tempalte_post(self, **kwargs):  # noqa: E501
        """下载模板模型文件 Download template files  # noqa: E501

        根据文件名下载模板模型文件 Download model template files with fileName  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v2_model_configuration_template_download_model_tempalte_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param DownloadFileInput download_file_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v2_model_configuration_template_download_model_tempalte_post_with_http_info(**kwargs)  # noqa: E501

    def api_v2_model_configuration_template_download_model_tempalte_post_with_http_info(self, **kwargs):  # noqa: E501
        """下载模板模型文件 Download template files  # noqa: E501

        根据文件名下载模板模型文件 Download model template files with fileName  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v2_model_configuration_template_download_model_tempalte_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param DownloadFileInput download_file_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(str, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'download_file_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v2_model_configuration_template_download_model_tempalte_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'download_file_input' in local_var_params:
            body_params = local_var_params['download_file_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/model-configuration/template/download-model-tempalte', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v2_model_configuration_template_model_tempalte_list_get(self, **kwargs):  # noqa: E501
        """获取模板模型文件列表 Get template files list  # noqa: E501

        获取所有的模板模型文件列表 Get all the model template files list  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v2_model_configuration_template_model_tempalte_list_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[QueryTemplateListOutput]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v2_model_configuration_template_model_tempalte_list_get_with_http_info(**kwargs)  # noqa: E501

    def api_v2_model_configuration_template_model_tempalte_list_get_with_http_info(self, **kwargs):  # noqa: E501
        """获取模板模型文件列表 Get template files list  # noqa: E501

        获取所有的模板模型文件列表 Get all the model template files list  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v2_model_configuration_template_model_tempalte_list_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[QueryTemplateListOutput], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v2_model_configuration_template_model_tempalte_list_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/model-configuration/template/model-tempalte-list', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[QueryTemplateListOutput]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v2_model_configuration_template_upload_model_template_post(self, **kwargs):  # noqa: E501
        """上传模型模板文件，同时检查模型文件 Upload a template file, meanwhile check the file  # noqa: E501

        上传模型模板文件，支持以.zip或者.7z格式来压缩一个完整的模型，同时会后台异步检查模型文件，如果模型文件符合要求，将被标记为可用于创建模板方案 Upload a template file, which can be a .zip or .7z file containing a complete model. Meanwhile the model files will be checked asynchronously, and marked as model file that can be used to create a template scenario if it meet the necessary requirements.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v2_model_configuration_template_upload_model_template_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str mupp_name: 模型文件名称 model file name without path
        :param str system_id: 系统ID system id
        :param str library_type: 库类型 library type
        :param str business_type: 业务类型 business type
        :param str model_type: 模型类型 model type
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v2_model_configuration_template_upload_model_template_post_with_http_info(**kwargs)  # noqa: E501

    def api_v2_model_configuration_template_upload_model_template_post_with_http_info(self, **kwargs):  # noqa: E501
        """上传模型模板文件，同时检查模型文件 Upload a template file, meanwhile check the file  # noqa: E501

        上传模型模板文件，支持以.zip或者.7z格式来压缩一个完整的模型，同时会后台异步检查模型文件，如果模型文件符合要求，将被标记为可用于创建模板方案 Upload a template file, which can be a .zip or .7z file containing a complete model. Meanwhile the model files will be checked asynchronously, and marked as model file that can be used to create a template scenario if it meet the necessary requirements.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v2_model_configuration_template_upload_model_template_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str mupp_name: 模型文件名称 model file name without path
        :param str system_id: 系统ID system id
        :param str library_type: 库类型 library type
        :param str business_type: 业务类型 business type
        :param str model_type: 模型类型 model type
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(str, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'mupp_name',
            'system_id',
            'library_type',
            'business_type',
            'model_type'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v2_model_configuration_template_upload_model_template_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'mupp_name' in local_var_params and local_var_params['mupp_name'] is not None:  # noqa: E501
            query_params.append(('muppName', local_var_params['mupp_name']))  # noqa: E501
        if 'system_id' in local_var_params and local_var_params['system_id'] is not None:  # noqa: E501
            query_params.append(('systemId', local_var_params['system_id']))  # noqa: E501
        if 'library_type' in local_var_params and local_var_params['library_type'] is not None:  # noqa: E501
            query_params.append(('libraryType', local_var_params['library_type']))  # noqa: E501
        if 'business_type' in local_var_params and local_var_params['business_type'] is not None:  # noqa: E501
            query_params.append(('businessType', local_var_params['business_type']))  # noqa: E501
        if 'model_type' in local_var_params and local_var_params['model_type'] is not None:  # noqa: E501
            query_params.append(('modelType', local_var_params['model_type']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/model-configuration/template/upload-model-template', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

# flake8: noqa
"""
    scenario-compute-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from dhicn_scenario_compute_service.models.dhi_dss_scenario_compute_dapr_services_dtos_auto_forecast_info import DhiDssScenarioComputeDaprServicesDtosAutoForecastInfo
from dhicn_scenario_compute_service.models.dhi_dss_scenario_compute_dapr_services_dtos_model_boundary_config_output import DhiDssScenarioComputeDaprServicesDtosModelBoundaryConfigOutput
from dhicn_scenario_compute_service.models.dhi_dss_scenario_compute_dapr_services_dtos_point_express_item import DhiDssScenarioComputeDaprServicesDtosPointExpressItem
from dhicn_scenario_compute_service.models.dhi_dss_scenario_compute_dapr_services_dtos_run_model_info import DhiDssScenarioComputeDaprServicesDtosRunModelInfo
from dhicn_scenario_compute_service.models.dhi_dss_scenario_compute_rf_dtos_create_flood_storage_area_scenario_input import DhiDssScenarioComputeRfDtosCreateFloodStorageAreaScenarioInput
from dhicn_scenario_compute_service.models.dhi_dss_scenario_compute_rf_dtos_create_schedule_scenario_input import DhiDssScenarioComputeRfDtosCreateScheduleScenarioInput
from dhicn_scenario_compute_service.models.dhi_dss_scenario_compute_scenario_dtos_create_auto_scenario_input import DhiDssScenarioComputeScenarioDtosCreateAutoScenarioInput
from dhicn_scenario_compute_service.models.dhi_dss_scenario_compute_scenario_dtos_create_manual_scenario_input import DhiDssScenarioComputeScenarioDtosCreateManualScenarioInput
from dhicn_scenario_compute_service.models.dhi_dss_scenario_compute_scenario_dtos_create_response_scenario_input import DhiDssScenarioComputeScenarioDtosCreateResponseScenarioInput
from dhicn_scenario_compute_service.models.dhi_dss_scenario_compute_scenario_dtos_create_scene_scenario_input import DhiDssScenarioComputeScenarioDtosCreateSceneScenarioInput
from dhicn_scenario_compute_service.models.dhi_dss_scenario_compute_scenario_dtos_create_schedule_scenario_input import DhiDssScenarioComputeScenarioDtosCreateScheduleScenarioInput
from dhicn_scenario_compute_service.models.dhi_dss_scenario_compute_scenario_dtos_create_wq_accident_scenario_input import DhiDssScenarioComputeScenarioDtosCreateWqAccidentScenarioInput
from dhicn_scenario_compute_service.models.dhi_dss_scenario_compute_scenario_dtos_device_indicator_output import DhiDssScenarioComputeScenarioDtosDeviceIndicatorOutput
from dhicn_scenario_compute_service.models.dhi_dss_scenario_compute_scenario_dtos_scenario_info import DhiDssScenarioComputeScenarioDtosScenarioInfo
from dhicn_scenario_compute_service.models.dhi_dss_scenario_compute_wd_dtos_create_wd_close_valve_scenario_input import DhiDssScenarioComputeWdDtosCreateWdCloseValveScenarioInput
from dhicn_scenario_compute_service.models.dhi_dss_scenario_compute_wd_dtos_create_wd_flushing_scenario_input import DhiDssScenarioComputeWdDtosCreateWdFlushingScenarioInput
from dhicn_scenario_compute_service.models.dhi_dss_scenario_compute_wd_dtos_create_wd_pipe_burst_accident_scenario_input import DhiDssScenarioComputeWdDtosCreateWdPipeBurstAccidentScenarioInput
from dhicn_scenario_compute_service.models.dhi_dss_scenario_compute_wd_dtos_create_wd_planning_scenario_input import DhiDssScenarioComputeWdDtosCreateWdPlanningScenarioInput
from dhicn_scenario_compute_service.models.dhi_dss_scenario_compute_wd_dtos_create_wd_schedule_scenario_input import DhiDssScenarioComputeWdDtosCreateWdScheduleScenarioInput
from dhicn_scenario_compute_service.models.dhi_dss_scenario_compute_wd_dtos_create_wd_water_hammer_scenario_input import DhiDssScenarioComputeWdDtosCreateWdWaterHammerScenarioInput
from dhicn_scenario_compute_service.models.dhi_dss_scenario_compute_wd_dtos_create_wdwq_accident_scenario_input import DhiDssScenarioComputeWdDtosCreateWdwqAccidentScenarioInput
from dhicn_scenario_compute_service.models.volo_abp_http_remote_service_error_info import VoloAbpHttpRemoteServiceErrorInfo
from dhicn_scenario_compute_service.models.volo_abp_http_remote_service_error_response import VoloAbpHttpRemoteServiceErrorResponse
from dhicn_scenario_compute_service.models.volo_abp_http_remote_service_validation_error_info import VoloAbpHttpRemoteServiceValidationErrorInfo



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from dhicn_result_analysis_service.api.catchment_api import CatchmentApi
from dhicn_result_analysis_service.api.log_simulation_api import LogSimulationApi
from dhicn_result_analysis_service.api.m2_d_api import M2DApi
from dhicn_result_analysis_service.api.network_api import NetworkApi
from dhicn_result_analysis_service.api.rain_log_api import RainLogApi
from dhicn_result_analysis_service.api.river_api import RiverApi
from dhicn_result_analysis_service.api.scenario_api import ScenarioApi
from dhicn_result_analysis_service.api.urban_cs_result_analysis_api import UrbanCsResultAnalysisApi
from dhicn_result_analysis_service.api.urban_flooding_api import UrbanFloodingApi
from dhicn_result_analysis_service.api.urban_wd_result_analysis_api import UrbanWdResultAnalysisApi
from dhicn_result_analysis_service.api.urban_wd_time_series_api import UrbanWdTimeSeriesApi
from dhicn_result_analysis_service.api.wd_test_api import WDTestApi
from dhicn_result_analysis_service.api.wq_test_api import WQTestApi
from dhicn_result_analysis_service.api.water_hammer_result_analysis_api import WaterHammerResultAnalysisApi
from dhicn_result_analysis_service.api.wq_result_analysis_api import WqResultAnalysisApi
